##
## objexport.py
## Writes the selected mesh to Wavefront OBJ.
## Copyright (C) 2002 MiKael NAVARRO
##
## This library is free software; you can redistribute it and/or
## modify it under the terms of the GNU Library General Public
## License as published by the Free Software Foundation; either
## version 2 of the License, or (at your option) any later version.
##
## This library is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## Library General Public License for more details.
##
## You should have received a copy of the GNU Library General Public
## License along with this library; if not, write to the
## Free Software Foundation, Inc., 59 Temple Place - Suite 330,
## Boston, MA  02111-1307, USA.
##

## Script writing the active object on disk
## (in Alias Wavefront OBJ format).

import Blender # Blender API
import sys
from Blender import NMesh, Object

# Get list of all selected objects
object = Object.GetSelected()
# Get active object
objname = object[0].getName()
# Low level mesh access
meshname = object[0].data.name
nmesh = NMesh.GetRaw(meshname)

filename = objname + ".obj"
file = open(filename, "w")
print "exporting %s ..." % objname

std = sys.stdout
sys.stdout = file

# Comments
print "# object", objname
print "# nb_vertices", len(nmesh.verts)
print "# nb_faces", len(nmesh.faces)
print

# Write object name (optional)
#print "o", objname
#print

# Get object size
sx, sy, sz = object[0].size

# Write vertices
for vertex in nmesh.verts:
  vx, vy, vz = vertex.co
  print "v %f %f %f" % (vx*sx, vy*sy, vz*sz)
print

# Writing texcoords
if nmesh.hasVertexUV():
  for vertex in nmesh.verts:
    vtx, vty, vtz = vertex.uvco
    print "vt %f %f %f" % (vtx, vty, vtz)
  print

#Writing normals
for vertex in nmesh.verts:
  vnx, vny, vnz = vertex.no
  print "vn %f %f %f" % (vnx, vny, vnz)
print

# Write group name (= objname)
print "g", objname
print

# Write faces indexes
for face in nmesh.faces:
  print "f",
  face.v.reverse() # flips face orientation
  for vertex in face.v:
    idx = vertex.index + 1
    if nmesh.hasVertexUV():
      print "%d/%d/%d" % (idx, idx, idx),
    else:
      print "%d//%d" % (idx, idx),
  print

sys.stdout = std
file.close()

print "... saved to", filename

